#include <stdlib.h>
#include <stdio.h>
#include <avr/io.h>
#include <avr/iom644.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <string.h>
#include <stdint.h>
//#include <float.h>

#include "uart.h"

/* define CPU frequency in Mhz here if not defined in Makefile */
#ifndef F_CPU
#define F_CPU 16000000UL
#endif

/* 38400 baud */
#define UART_BAUD_RATE      38400

volatile uint16_t millisekunden=0;
volatile uint8_t sekunde=0;
volatile uint8_t minute=0;
volatile uint16_t stunde=0;
volatile uint16_t disp_refresh=0;

void systemInit(void) {
DDRC = 0b11111111;
PORTC = 0b00000000;
DDRA = 0b11110000;
PORTA = 0b00001111;
}

void timerInit(void) {
	TCCR0A = (1 << WGM01); //Mode2: CTC Clear Timer on compare match
	TCCR0B = (1 << CS01) | (1 << CS00); // prescaler = 64
	OCR0A = 250; //250 Takte = 1ms

	TIMSK0 = (1 << OCIE0A); //Compare Interrupt aktivieren
}
void wheelInterruptInit(void) {
	EICRA = 0b00000001;
	EIMSK = 0b00000001;
}



ISR (TIMER0_COMPA_vect) {
	millisekunden++;
	if(millisekunden == 1000) {
		sekunde++;
		millisekunden = 0;
		if(sekunde == 60) {
			minute++;
			sekunde = 0;
		    if(minute == 60) {
		    	stunde++;
		    	minute = 0;
		    }
		}
	}
}

int main(void) {
	cli();
	systemInit();
	timerInit();
	//Initialize UART library, pass baudrate and AVR cpu clock with the macro
    uart_init( UART_BAUD_SELECT(UART_BAUD_RATE,F_CPU) );
    sei();
    PORTC |= (1 << 7); // LED8 zeigt den Betrieb an.
    uart_puts("\n\nTacho Programm gestartet!\n\r");
    while(1) {
		PORTC |= (1 << 6);
	}
}
